HOWTOs
******

This section contains practical **how-to guides**, instructions, and tutorials.
These are intended to illustrate and demonstrate how to work with TDC-compliant data and metadata,
and develop code and other tools that process such (meta)data.

Put another way, a HOWTO shows *just one possible, suggested, or recommended* way to comply with the standards.
In contrast, the :doc:`/standards` are *prescriptive*.

.. toctree::
   :maxdepth: 2

   Edit data structures <cli-edit>
   Format data <data-csv>
   Record and update metadata <metadata>
   Create records via the portal <portal>
